.. _Developing:

=================
Developer's guide
=================

.. _Extending cgatreport:

Extending CGATReport
======================

cgatreport provides a component architecture 
for adding new capabilities. Components provide the following 
functions:

render
   create a plot or table

transform
   manipulate the data


Modules documentation
=====================

.. toctree::
   :maxdepth: 2

   Renderer.rst
   Plotter.rst
   Transformer.rst
   Server.rst
   Tracker.rst
   DataTypes.rst

Contributions
=============

The following people contributed to CGATReport:

Andreas Heger 
Ian Sudbery

Indices and tables
==================

This is some text

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

